#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_dj-monaco
------------

Tests for `dj-monaco` models module.
"""

from django.test import TestCase

from djmonaco import models


class TestDjmonaco(TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
